==> qt-creator-opensource-src-4.0.2.zip: qt-creator-opensource-src-4.0.2/src/plugins/winrt/winrtphoneqtversion.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef WINRTPHONEQTVERSION_H
#define WINRTPHONEQTVERSION_H

#include "winrtqtversion.h"

namespace WinRt {
namespace Internal {

class WinRtPhoneQtVersion : public WinRtQtVersion
{
    Q_DECLARE_TR_FUNCTIONS(WinRt::Internal::WinRtQtVersion)
public:
    WinRtPhoneQtVersion() = default;
    WinRtPhoneQtVersion(const Utils::FileName &path, bool isAutodetected,
                        const QString &autodetectionSource);

    QString description() const;
    BaseQtVersion *clone() const;
    QString type() const;
    QSet<Core::Id> targetDeviceTypes() const;
};

} // Internal
} // WinRt

#endif // WINRTPHONEQTVERSION_H

==> qt-creator-opensource-src-4.5.2.zip: qt-creator-opensource-src-4.5.2/src/plugins/winrt/winrtphoneqtversion.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "winrtqtversion.h"

namespace WinRt {
namespace Internal {

class WinRtPhoneQtVersion : public WinRtQtVersion
{
    Q_DECLARE_TR_FUNCTIONS(WinRt::Internal::WinRtQtVersion)
public:
    WinRtPhoneQtVersion() = default;
    WinRtPhoneQtVersion(const Utils::FileName &path, bool isAutodetected,
                        const QString &autodetectionSource);

    QString description() const;
    BaseQtVersion *clone() const;
    QString type() const;
    QSet<Core::Id> targetDeviceTypes() const;
};

} // Internal
} // WinRt
